#delimit;
capture log close;
log using do/fdexp,replace;
*************************************************************;
*                                                           *;
*    Name    : FDEXP.DO                                     *;
*    OBJECTIVE: Create food expenditure data                *;
*                                                           *;
*************************************************************;
clear;
set more 1;
set log linesize 132;
set display linesize 132;

use sec10;

merge hhnum using corehh;
drop if _merge==1; *hh 460125 -- incomplete questionnaire;
keep hhnum hhsize bashki fooditem fpurqua fpurval fdprod fdreceiv;
sort hhnum fooditem;

merge hhnum fooditem using fdprice;
tab _merge;
keep hhnum hhsize bashki fooditem fpurqua fpurval fdprod fdreceiv 
     fdprice2 poutlier;

**correction to data for household 470511 -- (inv2.do identifies this
  household as having double-counted in that recorded purchased wheat
  *and* recorded home produced bread)
;
replace fpurqua=. if hhnum==470511&fooditem==102;

*replace missing values in fpurqua when have info on fpurval
;
replace fpurqua=fpurval/fdprice2 if fpurqua==. & fpurval~=. & fpurval~=0;

**identify outliers
;
egen fdq_tot=rsum(fpurqua fdprod fdreceiv);
gen fdq_pc=fdq_tot/hhsize;

egen mean1=mean(fdq_pc), by(fooditem);
egen sd1=sd(fdq_pc), by(fooditem);

gen upper1=mean1+sd1*3;
gen upper2=mean1*5;
gen outlier=1 if (fdq_pc>upper1 & fdq_pc~=.) & 
                 (fdq_pc>upper2 & fdq_pc~=.);

format fdq_pc %5.2f;

*tab fooditem, sum(fdq_pc);
tab fooditem if outlier==1; *# occurences of outliers;

**calculate median values (calc. over non-outliers) and replace.  Note at this
  stage we only want to replace outliers (and not missing values as well) 
  with means (but then again there shouldn't be any missing values...)
;

replace fdq_pc=. if outlier==1;
sort bashki fooditem;
egen medianq=median(fdq_pc), by(bashki fooditem);
egen medianq2=median(fdq_pc), by(fooditem);

gen fdq_pc2=fdq_pc;
replace fdq_pc2=medianq if outlier==1;
replace fdq_pc2=medianq2 if outlier==1 & fdq_pc2==.;

gen fdq_tot2=fdq_pc2*hhsize;

gen fdexpi=fdq_tot*fdprice2;
gen fdexpi2=fdq_tot2*fdprice2;

*following rescaling is necessary to ensure that components add to total -- 
this is necessary because adjusted outliers at the *aggregate* (i.e. sum of 
purchased, produced and received) level
;
gen fpurqua2=fpurqua*(fdq_tot2/fdq_tot) if fdq_tot~=0;
gen fdprod2=fdprod*(fdq_tot2/fdq_tot) if fdq_tot~=0;
gen fdrecei2=fdreceiv*(fdq_tot2/fdq_tot) if fdq_tot~=0;

gen pur_exi=fpurqua*fdprice2;
gen prd_exi=fdprod*fdprice2;
gen rec_exi=fdreceiv*fdprice2;
gen pur_exi2=fpurqua2*fdprice2;
gen prd_exi2=fdprod2*fdprice2;
gen rec_exi2=fdrecei2*fdprice2;

replace fdexpi=0 if fdexpi==.; 
replace pur_exi=0 if pur_exi==.;
replace prd_exi=0 if prd_exi==.;
replace rec_exi=0 if rec_exi==.;
replace fdexpi2=0 if fdexpi2==.; 
replace pur_exi2=0 if pur_exi2==.;
replace prd_exi2=0 if prd_exi2==.;
replace rec_exi2=0 if rec_exi2==.;

***********************************************;
***aggregation, food expenditure shares etc.***;
***********************************************;

**create group code
;
gen grpitem=fooditem;
recode grpitem  101/202=1
                301/504=2
                601/610=3
                701/703=4
                801/806=5
                901/906=6
                1102/1202=7
                1204/1206=8
                1302=9
                ; 
label define grpitem
1  "cereals"
2  "veg & fruit"
3  "meat & eggs"     
4  "fish"
5  "milk & dairy"
6  "oils & fats"
7  "cond. & drinks"
8  "alcohol"
9  "prepared meals"
;

label value grpitem grpitem;
label variable grpitem "food groups"; 

save tempdat1, replace;

**save quantities data for calorie analysis;
keep hhnum hhsize bashki fooditem grpitem fdq_tot fdq_tot2 upper1 upper2 
     outlier poutlier;
sort hhnum;
lab data "fdquant: food quantities";
save fdquant, replace;

use tempdat1;

**create hhold level data - only work with non-(food quantity)-adjusted data
  at this stage
;
cap program drop temp2;
program define temp2;

sort hhnum;
local i = 1;
while `i' < 10 {;
                disp "i is now `i'";
                egen long fdexp_`i' = sum(fdexpi) if grpitem==`i', by(hhnum);  
                egen long fprod_`i' = sum(prd_exi) if grpitem==`i', by(hhnum);  
                egen long frec_`i' = sum(rec_exi) if grpitem==`i', by(hhnum);  
                sort hhnum grpitem;
                qui by hhnum grpitem: drop if grpitem==`i' & _n~=1;
                local i = `i' + 1;
              };
local i = 1;
while `i' < 10 {;
                disp "i is now `i'";
                egen a = mean(fdexp_`i'), by (hhnum);
                replace fdexp_`i' = a;
                egen b = mean(fprod_`i'), by (hhnum);
                replace fprod_`i' = b;
                egen c = mean(frec_`i'), by (hhnum);
                replace frec_`i' = c;
                drop a b c;
                local i = `i' + 1;
               };
end;
temp2;

save tempdat2, replace;

use tempdat2;

sort hhnum;
qui by hhnum: gen a=_n;
keep if a==1;
drop a;

**calculate shares of food expenditures from different sources
;
egen fdexp=rsum(fdexp_*);
egen fprod=rsum(fprod_*);
egen frec=rsum(frec_*);
gen prod_shr=0;
gen rec_shr=0;
replace prod_shr=fprod/fdexp if fdexp>0;
replace rec_shr=frec/fdexp if fdexp>0;

**calculate food shares
;
cap program drop temp3;
program define temp3;

local i = 1;
while `i' < 10 {;
                disp "i is now `i'";
                gen fdshr_`i'=0;
                replace fdshr_`i' = fdexp_`i'/fdexp if fdexp_`i'>0 & fdexp_`i'~=.;  
                local i = `i' + 1;
              };
end;
temp3;

gen cerea_xs = fdshr_1; 
gen vegfr_xs = fdshr_2; 
gen meat_xs = fdshr_3; 
gen fish_xs = fdshr_4; 
gen dair_xs = fdshr_5; 
gen oils_xs = fdshr_6; 
gen drin_xs = fdshr_7; 
gen alco_xs = fdshr_8; 
gen prep_xs = fdshr_9; 

label variable prod_shr "Share of food exp home produced"; 
label variable rec_shr "Share of food exp rec. as gift"; 
label variable cerea_xs "Cereals, share food exp"; 
label variable vegfr_xs "veg & fruit, share food exp"; 
label variable meat_xs "meat & eggs, share of food exp"; 
label variable fish_xs "fish, share of food exp"; 
label variable dair_xs "dairy, share of food exp"; 
label variable oils_xs "oils, share of food exp"; 
label variable drin_xs "cond. & drnks, share of food exp"; 
label variable alco_xs "alcohol, share of food exp"; 
label variable prep_xs "prepared, share of food exp"; 

keep hhnum hhsize fdexp fprod frec fdexp_* fprod_* frec_* prod_shr rec_shr 
     cerea_xs vegfr_xs meat_xs fish_xs  dair_xs oils_xs drin_xs alco_xs 
     prep_xs; 
save fdexp, replace;

log close;
